@@ -1,10 +1,10 @@
 package lessons.lightbot;
 
+import lessons.lightbot.universe.LightBotEntity;
+import lessons.lightbot.universe.LightBotExercise;
+import lessons.lightbot.universe.LightBotWorld;
 import plm.core.model.lesson.Lesson;
 import plm.universe.Direction;
-import plm.universe.lightbot.LightBotEntity;
-import plm.universe.lightbot.LightBotExercise;
-import plm.universe.lightbot.LightBotWorld;
 
 public class Board09Castle extends LightBotExercise {
 
