@@ -2,7 +2,6 @@ package lessons.sort.basic.bubble;
 
 import plm.core.model.lesson.ExerciseTemplated;
 import plm.core.model.lesson.Lesson;
-import plm.universe.sort.SortingEntity;
 import plm.universe.sort.SortingWorld;
 
 public class AlgBubbleSort3 extends ExerciseTemplated {
@@ -14,9 +13,6 @@ public class AlgBubbleSort3 extends ExerciseTemplated {
 		myWorlds[0] = new SortingWorld("Functional test",10);
 		myWorlds[1] = new SortingWorld("Performance test (150 elms)",150);
 		
-		for ( int i = 0 ; i < myWorlds.length ; i++)
-			new SortingEntity("BubbleSort3",myWorlds[i]);
-
 		setup(myWorlds);
 	}
 }
