@@ -6,18 +6,19 @@ import lessons.welcome.array.array123.Array123;
 import lessons.welcome.array.array667.Array667;
 import lessons.welcome.array.arraycount9.ArrayCount9;
 import lessons.welcome.array.arrayfront9.ArrayFront9;
-import lessons.welcome.array.averagevalue.AverageValue;
 import lessons.welcome.array.basics.Array1;
 import lessons.welcome.array.basics.Array2;
-import lessons.welcome.array.maxvalue.Extrema;
 import lessons.welcome.array.golomb.Golomb;
 import lessons.welcome.array.has271.Has271;
-import lessons.welcome.array.indexof.maxvalue.IndexOfMaxValue;
-import lessons.welcome.array.indexof.value.IndexOfValue;
 import lessons.welcome.array.island.Island;
-import lessons.welcome.array.maxvalue.MaxValue;
 import lessons.welcome.array.notriples.NoTriples;
-import lessons.welcome.array.occurenceofvalue.OccurrenceOfValue;
+import lessons.welcome.array.search.AverageValue;
+import lessons.welcome.array.search.Extrema;
+import lessons.welcome.array.search.IndexOfMaxValue;
+import lessons.welcome.array.search.IndexOfValue;
+import lessons.welcome.array.search.MaxValue;
+import lessons.welcome.array.search.OccurrenceOfValue;
+import lessons.welcome.array.search.SecondMaxValue;
 import lessons.welcome.bat.bool1.Close10;
 import lessons.welcome.bat.bool1.CountTeen;
 import lessons.welcome.bat.bool1.Diff21;
@@ -65,14 +66,14 @@ import lessons.welcome.environment.Environment;
 import lessons.welcome.instructions.Instructions;
 import lessons.welcome.instructions.InstructionsDrawG;
 import lessons.welcome.loopdowhile.LoopDoWhile;
-import lessons.welcome.loopdowhile.Poucet;
+import lessons.welcome.loopdowhile.Poucet1;
+import lessons.welcome.loopdowhile.Poucet2;
 import lessons.welcome.loopfor.LoopCourse;
 import lessons.welcome.loopfor.LoopCourseForest;
 import lessons.welcome.loopfor.LoopFor;
 import lessons.welcome.loopfor.LoopStairs;
 import lessons.welcome.loopwhile.BaggleSeeker;
 import lessons.welcome.loopwhile.LoopWhile;
-import lessons.welcome.loopwhile.WhileMoria;
 import lessons.welcome.methods.args.MethodsArgs;
 import lessons.welcome.methods.basics.Methods;
 import lessons.welcome.methods.basics.MethodsDogHouse;
@@ -88,6 +89,7 @@ import lessons.welcome.methods.returning.MethodsReturning;
 import lessons.welcome.methods.slug.SlugHunting;
 import lessons.welcome.methods.slug.SlugSnail;
 import lessons.welcome.methods.slug.SlugTracking;
+import lessons.welcome.summative.Moria;
 import lessons.welcome.traversal.Snake;
 import lessons.welcome.traversal.column.TraversalByColumn;
 import lessons.welcome.traversal.diagonal.TraversalDiagonal;
@@ -114,7 +116,6 @@ public class Main extends Lesson {
 
 		Lecture loopWhile = addExercise(new LoopWhile(this));
 		addExercise(new BaggleSeeker(this), loopWhile);
-		addExercise(new WhileMoria(this),loopWhile);
 		
 		Lecture vars = addExercise(new Variables(this));
 		addExercise(new RunFour(this), vars);
@@ -128,7 +129,8 @@ public class Main extends Lesson {
 		addExercise(new LoopCourseForest(this),loopFor);
 		
 		Lecture loopDoWhile = addExercise(new LoopDoWhile(this));
-		addExercise(new Poucet(this), loopDoWhile);
+		addExercise(new Poucet1(this), loopDoWhile);
+		addExercise(new Poucet2(this), loopDoWhile);
 		
 		Lecture methodsVoid = addExercise(new Methods(this));
 		  addExercise(new MethodsDogHouse(this),methodsVoid);
@@ -202,6 +204,7 @@ public class Main extends Lesson {
 		addExercise(new MaxValue(this),arrays);
 		addExercise(new IndexOfMaxValue(this),arrays);
 		addExercise(new Extrema(this),arrays);
+		addExercise(new SecondMaxValue(this),arrays);
 		addExercise(new ArrayCount9(this),arrays);
 		addExercise(new ArrayFront9(this),arrays);
 		addExercise(new Array123(this),arrays);
@@ -219,5 +222,9 @@ public class Main extends Lesson {
 		addExercise(new TraversalZigZag(this),snake);
 		addExercise(new TraversalDiagonal(this),snake);
 		
+		// Other exercises
+		addExercise(new Moria(this));
+
+		
 	}
 }
