@@ -22,7 +22,7 @@ public class In1020 extends BatExercise {
 		myWorld.addTest(INVISIBLE, 10,42);
 		myWorld.addTest(INVISIBLE, 12,-2);
 
-		templatePython("in1020", 
+		templatePython("in1020", new String[] {"Int","Int"},
 				"def in1020(a, b):\n",
 				"   return (a>9 and a<21) or (b>9 and b<21)");
 		templateScala("in1020", new String[] {"Int","Int"},
