@@ -16,12 +16,12 @@ public class SleepIn extends BatExercise {
 		myWorld.addTest(INVISIBLE, false,true);
 		myWorld.addTest(INVISIBLE, true,true);
 
-		templatePython("sleepIn", 
+		templatePython("sleepIn", new String[] {"Boolean","Boolean"},
 				"def sleepIn(weekday, vacation):\n",
 				"    return not weekday or vacation\n");
 		templateScala("sleepIn", new String[] {"Boolean","Boolean"},
 				"def sleepIn(weekday:Boolean, vacation:Boolean): Boolean = {\n",
-				"  return !weekday || vacation;\n"
+				"  return !weekday || vacation;\n"
 				+ "}\n");
 		setup(myWorld);
 	}
