@@ -5,8 +5,8 @@ import java.awt.Color;
 import plm.core.model.lesson.ExerciseTemplated;
 import plm.core.model.lesson.Lesson;
 import plm.universe.Direction;
-import plm.universe.bugglequest.Buggle;
 import plm.universe.bugglequest.BuggleWorld;
+import plm.universe.bugglequest.SimpleBuggle;
 
 public class Conditions extends ExerciseTemplated {
 
@@ -16,7 +16,7 @@ public class Conditions extends ExerciseTemplated {
 				
 		BuggleWorld myWorld = new BuggleWorld("Closed World",7,7);
 		for (int i=0;i<7;i++) { 
-			new Buggle(myWorld, "Buggle "+(i+1), i, 3, Direction.NORTH, Color.black, Color.lightGray);
+			new SimpleBuggle(myWorld, "Buggle "+(i+1), i, 3, Direction.NORTH, Color.black, Color.lightGray);
 			if (i%2 == 0) {
 				myWorld.putTopWall(i, 3);
 				myWorld.putTopWall(i, 5);
