@@ -5,8 +5,8 @@ import java.awt.Color;
 import plm.core.model.lesson.ExerciseTemplated;
 import plm.core.model.lesson.Lesson;
 import plm.universe.Direction;
-import plm.universe.bugglequest.Buggle;
 import plm.universe.bugglequest.BuggleWorld;
+import plm.universe.bugglequest.SimpleBuggle;
 
 public class Instructions extends ExerciseTemplated {
 
@@ -15,7 +15,7 @@ public class Instructions extends ExerciseTemplated {
 		tabName="Program";
 
 		BuggleWorld myWorld = new BuggleWorld("Training World", 7,7);
-		new Buggle(myWorld, "Rookie", 2, 4, Direction.NORTH, Color.black, Color.lightGray);
+		new SimpleBuggle(myWorld, "Rookie", 2, 4, Direction.NORTH, Color.black, Color.lightGray);
 		
 		setup(myWorld);
 	}
