@@ -1,13 +1,13 @@
 def forward(i=1):
-    if i==1:
-      entity.forward()
-    else:
+    if i>1:
       errorMsg("Sorry Dave, I cannot let you use forward with an argument in this exercise. Use a loop instead.")
-def backward(i=1):
-    if i==1:
-      entity.backward()
     else:
+      entity.forward()
+def backward(i=1):
+    if i>1:
       errorMsg("Sorry Dave, I cannot let you use backward with an argument in this exercise. Use a loop instead.")
+    else:
+      entity.backward()
 # BEGIN SOLUTION
 cpt = 0
 
