@@ -1,13 +1,10 @@
 package lessons.welcome.methods.flowerpot;
 
-import java.awt.Color;
 import java.io.IOException;
 
 import plm.core.model.lesson.ExerciseTemplated;
 import plm.core.model.lesson.Lesson;
 import plm.universe.BrokenWorldFileException;
-import plm.universe.Direction;
-import plm.universe.bugglequest.Buggle;
 import plm.universe.bugglequest.BuggleWorld;
 
 public class FlowerCase extends ExerciseTemplated {
@@ -18,8 +15,6 @@ public class FlowerCase extends ExerciseTemplated {
 				(BuggleWorld) BuggleWorld.newFromFile("lessons/welcome/methods/flowerpot/FlowerCase")
 		};
 
-		new Buggle(myWorlds[0], "Van Gogh", 1, 2, Direction.EAST, Color.black, Color.lightGray);
-		
 		setup(myWorlds);
 	}
 }
