@@ -35,7 +35,6 @@ import org.xnap.commons.i18n.I18nFactory;
 import plm.core.GameListener;
 import plm.core.GameStateListener;
 import plm.core.HumanLangChangesListener;
-import plm.core.PLMEntityNotFound;
 import plm.core.ProgLangChangesListener;
 import plm.core.StatusStateListener;
 import plm.core.lang.LangC;
@@ -45,6 +44,7 @@ import plm.core.lang.LangPython;
 import plm.core.lang.LangRuby;
 import plm.core.lang.LangScala;
 import plm.core.lang.ProgrammingLanguage;
+import plm.core.model.lesson.ExecutionProgress;
 import plm.core.model.lesson.Exercise;
 import plm.core.model.lesson.Exercise.WorldKind;
 import plm.core.model.lesson.ExerciseTemplated;
@@ -54,6 +54,8 @@ import plm.core.model.lesson.Lesson.LoadingOutcome;
 import plm.core.model.session.GitSessionKit;
 import plm.core.model.session.ISessionKit;
 import plm.core.model.session.SessionDB;
+import plm.core.model.session.SourceFile;
+import plm.core.model.session.SourceFileRevertable;
 import plm.core.model.tracking.GitSpy;
 import plm.core.model.tracking.HeartBeatSpy;
 import plm.core.model.tracking.LocalFileSpy;
@@ -95,7 +97,7 @@ public class Game implements IWorldView {
 	private Course currentCourse;
 	private Lecture lastExercise;
 
-	public static final String [][] humanLangs = { {"English","en"}, {"Francais","fr"}, {"Italiano","it"}, {"Português brasileiro", "pt_BR"} };
+	public static final String [][] humanLangs = { {"English","en"}, {"Français","fr"}, {"Italiano","it"}, {"Português brasileiro", "pt_BR"}, {"中文", "zh"} };
 
 	public static final ProgrammingLanguage JAVA =       new LangJava();
 	public static final ProgrammingLanguage PYTHON =     new LangPython();
@@ -167,7 +169,7 @@ public class Game implements IWorldView {
 		if (checkScala())
 			System.err.println(i18n.tr("Scala is usable on your machine. Congratulations."));
 		else
-			System.err.println(i18n.tr("Please install Scala version 2.10 or higher to use it in the PLM."));
+			System.err.println(i18n.tr("Please install Scala version 2.11 or higher to use it in the PLM."));
 		if (checkPython())
 			System.err.println(i18n.tr("Jython is usable on your machine. Congratulations."));
 		else
@@ -231,7 +233,7 @@ public class Game implements IWorldView {
 
 	@SuppressWarnings({ "rawtypes", "unchecked" })
 	private boolean checkScala() {
-		String[] resources = new String[] {"/scala/tools/nsc/Interpreter", "/scala/ScalaObject", "/scala/reflect/io/AbstractFile"};
+		String[] resources = new String[] {"/scala/tools/nsc/Interpreter", "/scala/Unit",        "/scala/reflect/io/AbstractFile"};
 		String[] hints     = new String[] {"scala-compiler.jar",           "scala-library.jar",  "scala-reflect.jar"};
 		for (int i=0;i<resources.length;i++) {
 			scalaError = canResolve(resources[i],hints[i]);
@@ -335,9 +337,9 @@ public class Game implements IWorldView {
 	 */
 
 	public Lesson switchLesson(String lessonName, boolean failOnError) {
-		if (stepModeEnabled())
-			disableStepMode();
-
+		if(state==GameState.EXECUTION_STARTED || state == GameState.DEMO_STARTED) {
+			stopExerciseExecution();
+		}
 		this.setState(GameState.LOADING);
 		// Try caching the lesson to avoid the possibly long loading time during which we compute the solution of each exercise  
 		Lesson lesson = lessons.get(lessonName);
@@ -373,9 +375,9 @@ public class Game implements IWorldView {
 			e.printStackTrace();
 		}
 		// If a problem arose while setting up the lesson, don't switch 
-		// TODO: define a better solution when encountering this issue
 		if(lesson.getLoadingOutcomeState() == LoadingOutcome.FAIL) {
-			JOptionPane.showMessageDialog(null, i18n.tr("The lesson "+lesson.getName()+" encountered an issue while loading its exercises, please choose another lesson.") ,
+			JOptionPane.showMessageDialog(null, 
+					i18n.tr("The lesson {0} encountered an issue while loading its exercises, please report the issue and choose another lesson.",lesson.getName()) ,
 					i18n.tr("Broken lesson"), JOptionPane.ERROR_MESSAGE); 
 			return null;
 		}
@@ -473,6 +475,13 @@ public class Game implements IWorldView {
 
 	// only to avoid that exercise views register as listener of a lesson
 	public void setCurrentExercise(Lecture lect) {
+		// No need to stop the execution if no lesson is currently selected
+		if(currentLesson != null) {
+			// If already executing a program, stop it
+			if(state==GameState.EXECUTION_STARTED || state == GameState.DEMO_STARTED) {
+				stopExerciseExecution();
+			}
+		}
 		try {
 			saveSession(); // don't loose user changes
 			this.lastExercise = (currentLesson==null ? null : currentLesson.getCurrentExercise()); // save the last viewed exercise before switching7
@@ -579,9 +588,13 @@ public class Game implements IWorldView {
 		if (stepModeEnabled()) 
 			disableStepMode();
 
-		if (runner != null)
+		// Only forcefully stop the threads if they run the user code (not the correction)
+		if(state == GameState.EXECUTION_STARTED) {
 			runner.stopAll();
+		}			
 
+		// "Stop" the demo threads too, but asking them to not wait for the UI
+		// We cannot kill them as they are computing the exercise's correction.
 		Lecture lecture = this.currentLesson.getCurrentExercise();
 		if (lecture instanceof Exercise)
 			for (World w : ((Exercise) lecture).getWorlds(WorldKind.ANSWER))
@@ -593,6 +606,7 @@ public class Game implements IWorldView {
 		DemoRunner runner = new DemoRunner(Game.getInstance(), this.demoRunners);
 		runner.start();
 	}
+	
 	public void startExerciseStepExecution() {
 		stepMode = true;
 		startExerciseExecution();
@@ -657,6 +671,8 @@ public class Game implements IWorldView {
 		try {
 			// FIXME: this method is not called when pressing APPLE+Q on OSX
 
+			saveSession();
+			
 			// report user leave on the server
 			for(ProgressSpyListener spyListener: progressSpyListeners){
 				spyListener.leave();
@@ -665,7 +681,6 @@ public class Game implements IWorldView {
 			if(heartBeatSpy != null)
 				heartBeatSpy.die();
 
-			saveSession();
 			storeProperties();
 			System.exit(0);
 		} catch (UserAbortException e) {
@@ -998,6 +1013,8 @@ public class Game implements IWorldView {
 					return;
 			}
 			this.programmingLanguage = newLanguage;
+			if(getCurrentLesson() != null)
+				((Exercise)getCurrentLesson().getCurrentExercise()).lastResult = new ExecutionProgress();
 			fireProgLangChange(newLanguage);
 			if (newLanguage.equals(Game.JAVA) || newLanguage.equals(Game.PYTHON) || newLanguage.equals(Game.SCALA) || newLanguage.equals(Game.C)) // Only save it if it's stable enough
 				setProperty(PROP_PROGRAMING_LANGUAGE, newLanguage.getLang());
@@ -1054,10 +1071,12 @@ public class Game implements IWorldView {
 			System.out.println("Saving location: "+SAVE_DIR.getAbsolutePath());
 			System.out.println("Lesson: "+(l==null?"None loaded yet":l.getName()));
 			System.out.println("Exercise: "+(l==null?"None loaded yet":l.getCurrentExercise().getName()));
-			for (World w:((Exercise)l.getCurrentExercise()).getWorlds(WorldKind.ANSWER)) {
-				String s = w.getDebugInfo();
-				if (s != "") 
-					System.out.println("World: "+s);
+			if(l!=null) {
+				for (World w:((Exercise)l.getCurrentExercise()).getWorlds(WorldKind.ANSWER)) {
+					String s = w.getDebugInfo();
+					if (s != "") 
+						System.out.println("World: "+s);
+				}
 			}
 			System.out.println("PLM version: "+Game.getProperty("plm.major.version","internal",false)+" ("+Game.getProperty("plm.major.version","internal",false)+"."+Game.getProperty("plm.minor.version","",false)+")");
 			System.out.println("Java version: "+System.getProperty("java.version")+" (VM: "+ System.getProperty("java.vm.name")+" "+ System.getProperty("java.vm.version")+")");
@@ -1187,4 +1206,23 @@ public class Game implements IWorldView {
 	public static String getSavingLocation() {
 		return SAVE_DIR.getPath();
 	}
+
+	public void revertExo() {
+		Lecture lect = getCurrentLesson().getCurrentExercise();
+		if (! (lect instanceof Exercise)) 
+			return;
+
+		Exercise ex = (Exercise) lect;
+		for (ProgrammingLanguage lang: ex.getProgLanguages())
+			for (int i=0; i<ex.getSourceFileCount(lang); i++) {
+				SourceFile sf = ex.getSourceFile(lang,i);
+				if (sf instanceof SourceFileRevertable)
+					((SourceFileRevertable) sf).revert();
+			}
+		for (ProgrammingLanguage pl:Game.programmingLanguages)
+			Game.getInstance().studentWork.setPassed(ex, pl, false);
+		for (ProgressSpyListener l : this.progressSpyListeners) {
+			l.reverted(ex);
+		}
+	}
 }
