@@ -6,9 +6,6 @@ package plm.core.model;
  */
 public class UserAbortException extends Exception {
 	private static final long serialVersionUID = 1L;
-	public UserAbortException(String msg) {
-		super(msg);
-	}
 	public UserAbortException(String msg, Exception ex) {
 		super(msg,ex);
 	}
