@@ -1,6 +1,7 @@
 package plm.core.model.lesson;
 
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.HashMap;
 import java.util.List;
@@ -9,8 +10,11 @@ import java.util.Vector;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
+import plm.core.PLMCompilerException;
+import plm.core.PLMEntityNotFound;
+import plm.core.lang.ProgrammingLanguage;
 import plm.core.model.Game;
-import plm.core.model.ProgrammingLanguage;
+import plm.core.model.lesson.Lesson.LoadingOutcome;
 import plm.core.model.session.SourceFile;
 import plm.core.utils.FileUtils;
 import plm.universe.BrokenWorldFileException;
@@ -34,7 +38,7 @@ public abstract class ExerciseTemplated extends Exercise {
 		newSourceFromFile(lang, name, filename, "");
 	}
 	public void newSourceFromFile(ProgrammingLanguage lang, String name, String filename,String patternString) throws NoSuchEntityException {
-
+		
 		String shownFilename =  filename.replaceAll("\\.", "/")+"."+lang.getExt();
 		StringBuffer sb = null;
 		try {
@@ -67,6 +71,7 @@ public abstract class ExerciseTemplated extends Exercise {
 		                                             */
 		StringBuffer skel = new StringBuffer(); /* within BEGIN/END SKEL */
 		StringBuffer correction = new StringBuffer(); /* the unchanged content, but the package and className modification */
+		boolean containsLinePreprocessor=false;
 
 		boolean seenTemplate=false; // whether B/E SOLUTION seems included within B/E TEMPLATE
 		for (String line : content.split("\n")) {
@@ -82,11 +87,22 @@ public abstract class ExerciseTemplated extends Exercise {
 				} else if (line.contains("package")) {
 					head.append("$package \n");	
 					correction.append("$package \n");
-				} else if (line.contains("BEGIN TEMPLATE")) {
+				} else if(line.contains("#line") && lang.equals(Game.C)){
+					containsLinePreprocessor=true;
+					head.append(line+"\n");
+				}else if (line.contains("BEGIN TEMPLATE")) {
+					if(!containsLinePreprocessor && lang.equals(Game.C)){
+						head.append("#line 1 \""+name+".c\" \n");
+						containsLinePreprocessor=true;
+					}
 					correction.append(line+"\n");
 					seenTemplate = true;
 					state = 1;
 				} else if (line.contains("BEGIN SOLUTION")) {
+					if(!containsLinePreprocessor && lang.equals(Game.C)){
+						head.append("#line 1 \""+name+".c\" \n");
+						containsLinePreprocessor=true;
+					}
 					correction.append(line+"\n");
 					state = 2; 
 				} else if (line.contains("BEGIN SKEL")) {
@@ -103,9 +119,9 @@ public abstract class ExerciseTemplated extends Exercise {
 				if (line.contains("BEGIN TEMPLATE")) {
 					System.out.println(i18n.tr("{0}: BEGIN TEMPLATE within the template. Please fix your entity.",shownFilename));
 					state = 4;
-				} else if (line.contains("public class "))
+				} else if (line.contains("public class ")){
 					templateHead.append(line.replaceAll("public class \\S*", "public class "+name)+"\n");
-				else if (line.contains("END TEMPLATE")) {
+				}else if (line.contains("END TEMPLATE")) {
 					state = 4;
 				} else if (line.contains("BEGIN SOLUTION")) {
 					state = 2; 
@@ -196,12 +212,12 @@ public abstract class ExerciseTemplated extends Exercise {
 		String initialContent = templateHead.toString() + templateTail.toString();
 		String skelContent;
 		String headContent;
-		if (lang == Game.PYTHON || lang == Game.SCALA) { 
+		if (lang == Game.PYTHON || lang == Game.SCALA || lang == Game.C) { 
 			skelContent = skel.toString();
 			headContent = head.toString();
 		} else {
-			skelContent = skel.toString().replaceAll("\n", " ");
-			headContent = head.toString().replaceAll("\n", " ");
+			skelContent = skel.toString().replaceAll("\r\n", " ").replaceAll("\n", " "); // remove Windows and Linux EOF
+			headContent = head.toString().replaceAll("\r\n", " ").replaceAll("\n", " "); // remove Windows and Linux EOF
 		}
 
 		String template = (headContent+"$body"+tail);
@@ -311,7 +327,7 @@ public abstract class ExerciseTemplated extends Exercise {
 	protected final void setup(World w) {
 		setup(new World[] {w});
 	}
-	protected void setup(World[] ws) {
+	protected <W extends World> void setup(W[] ws) {
 		boolean foundALanguage=false;
 		setupWorlds(ws);
 
@@ -321,7 +337,7 @@ public abstract class ExerciseTemplated extends Exercise {
 			for (SourceFile sf : getSourceFilesList(lang)) {
 				if (searchedName == null) {//lazy initialization if there is any sourcefile to parse
 					Pattern p = Pattern.compile(".*?([^.]*)$");
-					Matcher m = p.matcher(nameOfCorrectionEntity);
+					Matcher m = p.matcher(lang.nameOfCorrectionEntity(this));
 					if (m.matches())
 						searchedName = m.group(1);
 					p = Pattern.compile("Entity$");
@@ -335,11 +351,11 @@ public abstract class ExerciseTemplated extends Exercise {
 			}
 			if (!foundThisLanguage) {
 				try {
-					newSourceFromFile(lang, tabName, nameOfCorrectionEntity);
+					newSourceFromFile(lang, tabName, lang.nameOfCorrectionEntity(this));
 					super.addProgLanguage(lang);
 					foundALanguage = true;
 					if (Game.getInstance().isDebugEnabled())
-						System.out.println("Found suitable templating entity "+nameOfCorrectionEntity+" in "+lang);
+						System.out.println("Found suitable templating entity "+lang.nameOfCorrectionEntity(this)+" in "+lang);
 
 				} catch (NoSuchEntityException e) {
 					if (lang.equals(Game.PYTHON) || lang.equals(Game.SCALA) || lang.equals(Game.JAVA)) 
@@ -362,6 +378,15 @@ public abstract class ExerciseTemplated extends Exercise {
 	}
 	
 	protected void computeAnswer() {
+		final String id = this.getId();
+		Thread.UncaughtExceptionHandler h = new Thread.UncaughtExceptionHandler() {
+		    public void uncaughtException(Thread th, Throwable ex) {
+		    	if(ex instanceof PLMEntityNotFound) {
+		    		getLesson().setLoadingOutcomeState(LoadingOutcome.FAIL);
+		    	}
+		        System.err.println("Uncaught exception while computing answer: " + ex);
+		    }
+		};
 		Thread t = new Thread() {
 			@Override
 			public void run() {
@@ -381,6 +406,10 @@ public abstract class ExerciseTemplated extends Exercise {
 								System.err.println(i18n.tr("World {0} is broken ({1}). Recompute all answer worlds.",name,bwfe.getLocalizedMessage()) );
 								allFound = false;
 								break;
+							} catch (FileNotFoundException fnf) {
+								System.err.println(i18n.tr("Cache file {0} is missing. Recompute all answer worlds.",name,fnf.getLocalizedMessage()));
+								allFound = false;
+								break;
 							} catch (IOException ioe) {
 								System.err.println(i18n.tr("IO exception while reading world {0} ({1}). Recompute all answer worlds.",name,ioe.getLocalizedMessage()));
 								allFound = false;
@@ -400,11 +429,26 @@ public abstract class ExerciseTemplated extends Exercise {
 				/* I/O didn't work. We have to load the files manually */
 				ExecutionProgress progress = new ExecutionProgress();
 				
+				// In all language but C, the correction is either directly usable (interpreted) or already compiled in the jarfile
+				if(Game.getProgrammingLanguage().equals(Game.C)){
+					try {
+						//TODO BAT remove if bat will be implemented in C
+						if(!id.contains("bat.string1.lessons.bat") && !id.contains("welcome.lessons.welcome.bat") && ! id.contains("welcome.lessons.welcome.array"))
+							compileAll(Game.getInstance().getOutputWriter(), StudentOrCorrection.CORRECTION);
+					} catch (PLMCompilerException e) {
+						System.err.println("Severe error: the correction of exercise "+id+" cannot be compiled in C. Please go fix your PLM.");
+						e.printStackTrace();
+						Game.getInstance().setState(Game.GameState.COMPILATION_ENDED);
+						Game.getInstance().setState(Game.GameState.EXECUTION_ENDED);
+					}
+				}
 				mutateEntities(WorldKind.ANSWER, StudentOrCorrection.CORRECTION);
 
 				for (World aw : answerWorld) {
-					for (Entity ent: aw.getEntities()) 
-						ent.runIt(progress);
+					for (Entity ent: aw.getEntities()) {
+						ent.setScript(Game.C, id);
+						Game.getProgrammingLanguage().runEntity(ent,progress);
+					}
 					aw.setAnswerWorld();
 				}
 				
@@ -429,6 +473,7 @@ public abstract class ExerciseTemplated extends Exercise {
 				Game.getInstance().statusArgRemove(getClass().getSimpleName());
 			}
 		};
+		t.setUncaughtExceptionHandler(h);
 		Game.addInitThread(t);
 		t.start();
 	}
