@@ -13,6 +13,7 @@ import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
+import java.io.BufferedReader;
 import java.io.File;
 import java.io.IOException;
 
@@ -47,12 +48,12 @@ public class ChooseLessonDialog extends JFrame {
 		initComponents(Game.getInstance());
 	}
 
-	private void initComponents(Game g) {
+	private void initComponents(Game g) {		
 		this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
 		this.addWindowListener(new WindowAdapter() {
 	        @Override
 	        public void windowClosing(WindowEvent event) {
-	            Game.getInstance().quit();
+	        	MainFrame.getInstance().quit();	        			
 	        }
 	    });
 		
@@ -77,7 +78,7 @@ public class ChooseLessonDialog extends JFrame {
 		LessonMatrix matrix = new LessonMatrix(overview, new String[][] { // WARNING, keep ExoTest.lessons synchronized
 				{"lessons/welcome", "lessons/maze", "lessons/turmites", "lessons/turtleart"},
 				{"lessons/sort/basic", "lessons/sort/dutchflag", "lessons/sort/baseball", "lessons/sort/pancake"},
-				{"lessons/recursion/cons", "lessons/recursion", "lessons/recursion/hanoi" },
+				{"lessons/recursion/cons", "lessons/recursion/lego", "lessons/recursion/hanoi" },
 				{"lessons/lightbot", "lessons/bat/string1", "lessons/lander" },
 		    }); 
 	
@@ -270,6 +271,9 @@ class LessonButton extends JButton {
 			}
 		});
 		addMouseListener(new MouseAdapter() {
+			String filename = path.replace('.', File.separatorChar)
+					+ "/short_desc";
+
 			@Override
 			public void mouseClicked(MouseEvent e) {
 				if (e.getClickCount() == 2) {
@@ -277,6 +281,27 @@ class LessonButton extends JButton {
 					overview.goOnDoubleClick();
 				}
 			}
+
+			@Override
+			public void mouseEntered(MouseEvent e) {
+
+				try {
+					BufferedReader buffer = FileUtils.newFileReader(filename,
+							"html", true);
+					String line = buffer.readLine();
+					while (!line.contains("<h3>")) {
+						line = buffer.readLine();
+					}
+
+					String title = line.replaceAll("<h3>|</h3>", "");
+
+					setToolTipText(title);
+					buffer.close();
+				} catch (IOException ex) {
+					ex.printStackTrace();
+				}
+
+			}
 		});
 	}
 }
