@@ -64,6 +64,7 @@ import plm.core.ui.action.StartExecution;
 import plm.core.ui.action.StepExecution;
 import plm.core.ui.action.StopExecution;
 import plm.core.ui.action.SwitchExo;
+import plm.core.ui.action.SwitchLesson;
 import plm.core.ui.action.SwitchUser;
 import plm.core.utils.FileUtils;
 import plm.universe.World;
@@ -82,6 +83,7 @@ public class MainFrame extends JFrame implements GameStateListener, GameListener
 	private JButton demoButton;
     private JToggleButton helpMeButton;
     private JButton exoChangeButton;
+    private JButton lessonChangeButton;
     
     private JMenu menuFile;
     private JMenuItem miFileSavePicture,miExoLoad,miExoSwitch,miExoExercise,miExoCourse,miFileQuit;
@@ -108,6 +110,12 @@ public class MainFrame extends JFrame implements GameStateListener, GameListener
 
 	private MainFrame() {
 		super(frameTitle);
+		
+		if (OSXAdapter.isMacOSX()) {
+			System.setProperty("apple.laf.useScreenMenuBar", "true");
+			System.setProperty("com.apple.mrj.application.apple.menu.about.name", "PLM");
+		}
+		
 		FileUtils.setLocale(this.getLocale());
 		initComponents(Game.getInstance());
 		this.keyListeners(exerciseView);
@@ -119,23 +127,13 @@ public class MainFrame extends JFrame implements GameStateListener, GameListener
 			MainFrame.instance = new MainFrame();
 		return MainFrame.instance;
 	}
-	
-	
-	// FIXME: useless since it is never called...
-	public static void doDispose() {
-		if (MainFrame.instance == null)
-			return;
-		MainFrame.instance.dispose();
-		MainFrame.instance = null;
-
-	}
 
 	private void initComponents(final Game g) {
 		this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
 		this.addWindowListener(new WindowAdapter() {
 	        @Override
 	        public void windowClosing(WindowEvent event) {
-	            Game.getInstance().quit();
+	            MainFrame.this.quit();
 	        }
 	    });		
 		getContentPane().setLayout(new BorderLayout());
@@ -439,8 +437,11 @@ public class MainFrame extends JFrame implements GameStateListener, GameListener
 
 		} else {
 			try {
-				OSXAdapter.setQuitHandler(this, getClass().getDeclaredMethod("quit", (Class[]) null));
-				OSXAdapter.setAboutHandler(this, getClass().getDeclaredMethod("about", (Class[]) null));
+				if (OSXAdapter.isMacOSX()) {
+					OSXAdapter.setQuitHandler(this, getClass().getDeclaredMethod("quit", (Class[]) null));
+					OSXAdapter.setAboutHandler(this, getClass().getDeclaredMethod("about", (Class[]) null));
+					OSXAdapter.enableFullScreenMode(this);
+				}
 			} catch (SecurityException e) {
 				e.printStackTrace();
 			} catch (NoSuchMethodException e) {
@@ -501,6 +502,9 @@ public class MainFrame extends JFrame implements GameStateListener, GameListener
         toolBar.add(helpMeButton);
 
         toolBar.addSeparator();
+
+        lessonChangeButton = new PropagatingButton(new SwitchLesson(g, i18n.tr("Switch lesson"), ResourcesCache.getIcon("img/btn-switch-lesson.png")));
+        toolBar.add(lessonChangeButton);
         
         exoChangeButton = new PropagatingButton(new SwitchExo(g, i18n.tr("Switch exercise"), ResourcesCache.getIcon("img/btn-switch-exo.png")));
         toolBar.add(exoChangeButton);
@@ -610,8 +614,14 @@ public class MainFrame extends JFrame implements GameStateListener, GameListener
 
 
 	public void quit() {
-		MainFrame.getInstance().dispose();
-		Game.getInstance().quit();
+		Thread t = new Thread(new Runnable() {
+			public void run() {
+				Game.getInstance().quit();
+			}
+		});
+		t.start();
+
+		JOptionPane.showMessageDialog(this, i18n.tr("Please wait, while the PLM is saving your session data."));		
 	}
 
 	public void about() {
